/**
 * @fileOverview
 * @name kth.puddingto.i18n.js
 * @author Kim il (blaxtar@kthcorp.com)
 * @version 20121114
 * @lastModified 2012-11-14
 * @created 2012-06-20
 * @description
 * <pre>
 * Pudding.to > Internationalization (다국어)
 *
 * classes:
 * - {@link kth.puddingto.i18n} Internationalization (다국어)
 * </pre>
 */
/*jslint browser:true, devel:true, white:false, nomen: true, plusplus:false, sloppy:true */
(function(global) {

/**
 * @class
 * @name kth.puddingto.i18n
 * @param {object} options Options
 * @example
kth.puddingto.i18n({
	defaultLocale: 'en',
	locale: '',
	exportTo: null
});
 */
kth.getPackage('kth.puddingto.i18n', (function(NAME, i18n) {
	var /* private static constants */
		_INSTANCE = null,
		
		_LOCALE = {
			ENGLISH: 'en',
			KOREAN: 'ko',
			JAPANESE: 'ja',
			CHINESE: 'zh'
		},
		
		_STYLESHEET = {
			AVAILABLE_LOCALES: [
				_LOCALE.ENGLISH,
				_LOCALE.JAPANESE
			],
			LINK: '<link rel="stylesheet" type="text/css" href="{{href}}">'
		},
		
		_MESSAGES = {
			'en' : {
				AGREE_TERMS: 'Agree',
				ALL: 'All',
				FACEBOOK_VERIFIED: 'Facebook account successfully verified!',
				BACK_TO_TOP: 'Back to Top',
				BAN: 'Ignore',
				BLOCK: 'Block',
				CONFIRM_BAN_USER: 'Don\'t you want to get a recommendation about this user again?',
				CONNECT: 'Connect',
				DISCONNECT_FB: 'Disconnect Pudding.to from Facebook account?',
				DISCONNECT_TW: 'Disconnect Pudding.to from Twitter account?',
				DONE: 'Done',
				EMAIL: 'E-mail',
				EMAIL_CONFIRM: [
						'{{email}}\n',
						'Please check your email address.\n',
						'If you lost your password,\n',
						'this is the email address we will send directions to.\n',
						'Would like to continue?'
					].join(''),
				EMAIL_DUPLICATED: 'The E-mail already exists.',
				EMAIL_INVALID: 'Invalid email. Please try again.',
				EMAIL_REQUIRED: 'Please enter your email.',
				EMOTIONS: ['Happy', 'Joyful', 'lonely', 'Stormy heart', 'Hearts-a-flutter', 'Everyday', 'Dot Dot Dot', 'Awesome!', 'OMG', 'Yummy', 'Traveling', 'Partying', 'Self-Shot', 'Pet Lover', 'Photo by'],
				ENTER_EMAIL: 'Enter the Email account you used when registering.',
				ENTER_NICKNAME: 'Please enter your username or real name.',
				FILL_EMAIL: 'Your E-mail address',
				FILL_FIELDS: 'You must fill in all the blanks.',
				FILL_PASSWORD: 'more 6 characters',
				FILL_PASSWORD_CONFIRMATION: 'Retype password',
				FILL_PASSWORD_LOGIN: 'Your password.',
				FILL_USERNAME: '2-15 characters',
				FIND_FRIENDS: 'Find friends from facebook and twitter to share the fun.',
				FIND_FRIENDS_BUTTON: 'Find Friends',
				FOLLOW: 'Follow',
				FOLLOWER_SKYROCKETING: 'Suggested popular photomate',
				FOLLOWING: 'Following',
				FOLLOW_REQUESTED: 'Requested',
				FORGOT_EMAIL: 'Forgot E-mail',
				FORGOT_PASSWORD: 'Forgot Password',
				FRIENDS_IN_PUDDING: 'Friends using Pudding.to',
				FRIENDS_MAYKNOW_TITLE: 'Find your friends',
				HELP_ABOUT: 'Help',
				HELP_APPS: 'Other Apps from pudding',
				HELP_PUDDING_CAMERA: 'Pudding Camera',
				HELP_PUDDING_FACE: 'Korean Celeb Face Match',
				HELP_BLOG: 'Pudding.to blog',
				HELP_TERMS: 'Terms of Service',
				HELP_PRIVACY: 'Privacy Policy',
				INVITE: 'Invite',
				INVITE_FRIENDS: 'Invite other friends',
				INVITED: 'Invited',
				LINK_MUTUAL_FRIENDS: '<a href="/" data-link="mutual-friends"><em>{{count}}</em> Mutual friends</a>',
				LOADING: 'Loading',
				LOADING_FRIENDS: 'Loading your friends list…',
				LOGIN: 'Log in',
				LOGIN_WITH_FACEBOOK: 'Log in with facebook',
				MAYKNOW_ALL_FOLLOWED: 'Awesome! You\'ve followed all your may know friends.<br>By getting more friends, you can find more photomates.',
				MUTUAL_FRIEND_HEADER: 'You have <em>{{count}}</em> mutual friends with {{name}}.',
				NICKNAME_OR_NAME: 'Username or Real Name',
				NONE_BLOCKS: 'There are no blocked users.',
				NONE_FEED_MY: 'New comments and likes for your photo will appear here.',
				NONE_FEED_FOLLOWER: 'The people you follow<br>haven\'t updated anything recently.',
				NONE_FOLLOWS: 'You have no followers.',
				NONE_FOLLOWINGS: 'You have no followings.',
				NONE_FRIENDS: 'Your friends aren\'t yet on Pudding.to.<br>Invite them.',
				NONE_FRIENDS_TO_INVITE: 'No friends to invite.',
				NONE_LOCATIONS_MINE: 'No Location tag.<br>Add Location you are when you<br>upload a photo.',
				NONE_LOCATIONS_OTHERS: 'No Location tag.',
				NONE_MAYKNOW_1: 'Find more friends by connecting to<br>Facebook and Twitter.<br>Make new photomates with Pudding.to!',
				NONE_MAYKNOW_2: 'Not finding anyone you know?<br>Find more friends by connecting to<br>Facebook and Twitter.<br>Make new photomates with Pudding.to!',
				NONE_MUSICS_MINE: 'No Music tag.<br>Add music you like when you<br>upload a photo.',
				NONE_MUSICS_OTHERS: 'No Music tag.',
				NONE_POPULAR_PHOTOS: 'No popular photos yet.',
				NONE_SUGGESTED_FRIENDS: '<p class="cn3">There are no suggested friends.</p>',
				NONE_SUGGESTED_SIMILAR_FRIENDS: '<p class="cn3">If you upload photos with #tag, music, or POI, we will match photomates with similar taste.</p>',
				NONE_TAGS_MINE: 'Add #tag when you upload a photo<br>to find your photo mate.<br>E.g. #cat, #paris',
				NONE_TAGS_OTHERS: 'No # tag.',
				NONE_USER: '\'{{name}}\' does not exist!',
				PASSWORD: 'Password',
				PASSWORD_INVALID: 'Please check your password. (more 6 characters)',
				PASSWORD_REQUIRED: 'Please enter your password. (more 6 characters)',
				PASSWORD_CONFIRMATION: 'Confirm Password',
				PASSWORD_CONFIRMATION_REQUIRED: 'Please retype your password',
				PASSWORD_CONFIRMATION_INVALID: 'Please confirm your password.',
				PHOTO_UNIT: '{{count}} photo',
				PHOTOS_UNIT: '{{count}} photos',
				POPULAR_PHOTO: 'Awesome! Selected as Popular Photo!',
				PRIVACY_POLICY: 'Privacy Policy',
				REPORT: 'Report',
				REPORT_SUCCEEDED: 'We\'ve recived a report. We will check up as soon as possible.',
				SEARCH_FRIENDS: 'Find Friends',
				SEARCH_FRIENDS_DIRECTLY: 'Search (Username or Full name)',
				SEARCH_RESULT: 'search results',
				SEE_MORE: 'See more',
				SELECT: 'Select',
				SENT_FORGOT_PASSWORD: '\'Reset Password\' link has been sent to {{email}}',
				SERVER_ERROR: 'We are unable to load information, please try again later.',
				SHOW_TERMS: '<a href="#terms-service">Terms of Service / Privacy Policy</a>',
				SIGNUP: 'Sign up',
				SIGNUP_WITH_FACEBOOK: 'Sign up with facebook',
				SIGNUP_WITH_ANOTHER_EMAIL: 'Try another E-mail account',
				SNS_DESC: 'If you connect your account to twitter or facebook, you can export your photos to your twitter and facebook account from Pudding.to.',
				SUGGESTED_FRIENDS: 'Suggested users based on tag, music, and more.',
				SUGGESTED_FIRST_FRIENDS: 'Start Pudding.to by following suggested friends.',
				TERM_REQUIRED: 'Term agreement required',
				TERMS_OF_SERVICE: 'Terms of Service',
				TIME_JUST_NOW: 'Just Now',
				TIME_SECOND_AGO: ' second ago',
				TIME_SECONDS_AGO: ' seconds ago',
				TIME_MINUTE_AGO: ' minute ago',
				TIME_MINUTES_AGO: ' minutes ago',
				TIME_HOUR_AGO: ' hour ago',
				TIME_HOURS_AGO: ' hours ago',
				TIME_DAY_AGO: ' day ago',
				TIME_DAYS_AGO: ' days ago',
				TIME_WEEK_AGO: ' week ago',
				TIME_WEEKS_AGO: ' weeks ago',
				TIME_MONTH_AGO: ' month ago',
				TIME_MONTHS_AGO: ' months ago',
				TIME_YEAR: 'year',
				TIME_YEARS: 'years',
				UNBLOCK: 'Unblock',
				USERNAME: 'Username',
				USERNAME_DUPLICATED: 'The username already exists.',
				USERNAME_INVALID: 'Please check your user name.',
				USERNAME_REQUIRED: 'Please enter your username. (2-15 characters, numbers,_)',
				WELCOME: 'Welcome {{nickname}} !<br>Find friends and enjoy Pudding.to together!',
				WRITE_COMMENT: 'Write comment',
				YOU: 'You!'
			},
			'ko': {
				AGREE_TERMS: '약관동의',
				ALL: '전체',
				FACEBOOK_VERIFIED: '페이스북 인증에 성공 하셨습니다.',
				BACK_TO_TOP: '맨 위로',
				BAN: '추천무시',
				BLOCK: '차단',
				CONFIRM_BAN_USER: '이 이용자를 다시는 추천받지 않으시겠습니까?',
				CONNECT: '연결',
				DISCONNECT_FB: '페이스북 계정 연동을 해제하시겠습니까?',
				DISCONNECT_TW: '트위터 계정 연동을 해제하시겠습니까?',
				DONE: '완료',
				EMAIL: '이메일',
				EMAIL_CONFIRM: [
						'{{email}}\n',
						'사용할 이메일 주소가 정확한지\n',
						'확인해 주세요.\n',
						'로그인 계정으로 사용되며,\n',
						'비밀번호를 분실할 경우\n',
						'입력한 주소로 메일이 발송됩니다.\n',
						'위 주소로 가입하시겠습니까?'
					].join(''),
				EMAIL_DUPLICATED: '이미 사용중인 이메일 입니다.',
				EMAIL_INVALID: '이메일을 정확하게 입력해 주세요.',
				EMAIL_REQUIRED: '이메일을 입력해 주세요.',
				EMOTIONS: ['기분좋은', '신나는', '외로운', '눈물나는', '두근두근', '일상의', '생각에 잠긴', 'oh~!', '대~박!', '냠냠', '여행중', '특별한 날', '셀카', 'Pet Lover', 'Photo by'],
				ENTER_EMAIL: '가입시 입력한 이메일을 입력해 주세요.',
				ENTER_NICKNAME: '가입한 닉네임이나 이름을 입력해 주세요.',
				FILL_EMAIL: 'abc@abc.com',
				FILL_FIELDS: '입력되지 않은 정보가 있습니다.',
				FILL_PASSWORD: '6자 이상 입력',
				FILL_PASSWORD_CONFIRMATION: '비밀번호 재입력',
				FILL_PASSWORD_LOGIN: '비밀번호를 입력해주세요.',
				FILL_USERNAME: '2~15자의 영문,숫자',
				FIND_FRIENDS: '친구를 찾아보세요!',
				FIND_FRIENDS_BUTTON: '친구찾기',
				FOLLOW: '팔로우',
				FOLLOWER_SKYROCKETING: '팔로워가 급상승한 친구!',
				FOLLOWING: '팔로잉',
				FOLLOW_REQUESTED: '신청완료', 
				FORGOT_EMAIL: '이메일 찾기',
				FORGOT_PASSWORD: '비밀번호 찾기',
				FRIENDS_IN_PUDDING: '푸딩.투를 이용중인 친구',
				FRIENDS_MAYKNOW_TITLE: '친구를 찾아보세요',
				HELP_ABOUT: '도움말/고객센터',
				HELP_APPS: '푸딩의 다른 앱 보기',
				HELP_PUDDING_CAMERA: '푸딩카메라',
				HELP_PUDDING_FACE: '푸딩 얼굴인식',
				HELP_BLOG: '푸딩.투 블로그',
				HELP_TERMS: '서비스 약관',
				HELP_PRIVACY: '개인정보 보호정책',
				INVITE: '초대',
				INVITE_FRIENDS: '다른 친구 초대하기',
				INVITED: '초대완료',
				LINK_MUTUAL_FRIENDS: '<a href="/" data-link="mutual-friends">함께 아는 친구 <em>{{count}}</em>명</a>',
				LOADING: '로드중',
				LOADING_FRIENDS: '친구를 불러오고 있습니다.',
				LOGIN: '로그인',
				LOGIN_WITH_FACEBOOK: '페이스북으로 로그인하기',
				MAYKNOW_ALL_FOLLOWED: '알만한 친구를 모두 팔로잉했어요.<br><br><strong>추천 친구</strong>에서 나와 어울릴만한<br>친구들을 만나보세요!',
				MUTUAL_FRIEND_HEADER: '{{name}} 님과 함께 아는 친구 {{count}}명',
				NICKNAME_OR_NAME: '닉네임,이름',
				NONE_BLOCKS: '차단된 이용자가 없습니다.',
				NONE_FEED_MY: '새 소식이 없습니다.<br>내 사진의 좋아요와 댓글 업데이트 소식을<br>알려드려요.',
				NONE_FEED_FOLLOWER: '내 팔로잉의 소식이 없습니다.<br>내 팔로잉에게 생긴 새로운 소식을<br>알려드려요.',
				NONE_FOLLOWS: '팔로워 친구가 한 명도 없네요.',
				NONE_FOLLOWINGS: '팔로잉 친구가 한 명도 없네요.',
				NONE_FRIENDS: '친구가 없습니다.',
				NONE_FRIENDS_TO_INVITE: '초대할 친구가 없습니다.',
				NONE_LOCATIONS_MINE: '장소태그가 없습니다.<br>사진을 올릴 때, 장소를 넣어 보세요.',
				NONE_LOCATIONS_OTHERS: '장소태그가 없습니다.',
				NONE_MAYKNOW_1: '페이스북, 트위터 연결을 하거나<br>푸딩.투에서 친구들을 팔로우하면<br>알만한 친구를 더 많이 만날 수 있어요.',
				NONE_MAYKNOW_2: '알만한 친구가 없다고 실망하지 마세요.<br><br>페이스북, 트위터 연결을 하거나<br>푸딩투 팔로우를 많이 할 수록<br>반가운 친구를 매일 찾아드립니다.',
				NONE_MUSICS_MINE: '음악태그가 없습니다.<br>사진을 올릴 때, 음악을 넣어 보세요.',
				NONE_MUSICS_OTHERS: '음악태그가 없습니다.',
				NONE_POPULAR_PHOTOS: '인기사진이 없습니다.',
				NONE_SUGGESTED_FRIENDS: '<p class="cn3">추천 친구가 없습니다.</p>',
				NONE_SUGGESTED_SIMILAR_FRIENDS: '<p class="cn3">사진과 함께 태그, 음악, 장소를 넣으면<br> 취향이 비슷한 친구를 만날 수 있어요!</p>',
				NONE_TAGS_MINE: '#태그가 없습니다.<br>사진을 올릴 때, #태그를 입력해 보세요.',
				NONE_TAGS_OTHERS: '#태그가 없습니다.',
				NONE_USER: '‘{{name}}’ 닉네임이나 이름을<br>가진 사람이 없습니다.',
				PASSWORD: '비밀번호',
				PASSWORD_INVALID: '비밀번호를 6자이상 입력해주세요.',
				PASSWORD_REQUIRED: '비밀번호를 입력해주세요. (6자 이상)',
				PASSWORD_CONFIRMATION: '비밀번호 확인',
				PASSWORD_CONFIRMATION_REQUIRED: '비밀번호를 한번더 입력해 주세요.',
				PASSWORD_CONFIRMATION_INVALID: '비밀번호가 일치하지 않습니다.',
				PHOTO_UNIT: '{{count}} 장',
				PHOTOS_UNIT: '{{count}} 장',
				POPULAR_PHOTO: '인기사진에 뽑혔어요~!',
				PRIVACY_POLICY: '개인정보 보호정책',
				REPORT: '신고하기',
				REPORT_SUCCEEDED: '신고가 접수되었습니다. 빠른시일내에 검토하여 처리하도록 하겠습니다.',
				SEARCH_FRIENDS: '친구 찾기',
				SEARCH_FRIENDS_DIRECTLY: '직접찾기 (닉네임, 이름)',
				SEARCH_RESULT: '검색 결과',
				SEE_MORE: '더보기',
				SELECT: '선택',
				SENT_FORGOT_PASSWORD: '{{email}}로 비밀번호를 재설정할 수 있는 링크를 보내드렸습니다.',
				SERVER_ERROR: '정보를 불러올 수 없습니다. 잠시 후 다시 시도해 주세요.',
				SHOW_TERMS: '<a href="#terms-service">약관/개인 정보취급방침</a> 동의',
				SIGNUP: '가입하기',
				SIGNUP_WITH_FACEBOOK: '페이스북으로 푸딩가입',
				SIGNUP_WITH_ANOTHER_EMAIL: '다른 이메일로 가입하기',
				SUGGESTED_FRIENDS: '태그,음악,장소가 같거나 인기 많은 친구',
				SUGGESTED_FIRST_FRIENDS: '추천친구들을 팔로잉하고 푸딩.투를 즐겨보세요!',
				SNS_DESC: '연동을 설정하면 푸딩.투에 올린 사진이 트위터, 페이스북에도 함께 보여집니다.',
				TERM_REQUIRED: '약관/개인 정보취급방침\n동의에 체크해주세요.',
				TERMS_OF_SERVICE: '서비스 약관',
				TIME_JUST_NOW: '방금 전',
				TIME_SECOND_AGO: '초 전',
				TIME_SECONDS_AGO: '초 전',
				TIME_MINUTE_AGO: '분 전',
				TIME_MINUTES_AGO: '분 전',
				TIME_HOUR_AGO: '시간 전',
				TIME_HOURS_AGO: '시간 전',
				TIME_DAY_AGO: '일 전',
				TIME_DAYS_AGO: '일 전',
				TIME_WEEK_AGO: '주 전',
				TIME_WEEKS_AGO: '주 전',
				TIME_MONTH_AGO: '개월 전',
				TIME_MONTHS_AGO: '개월 전',
				TIME_YEAR: '년',
				TIME_YEARS: '년',
				UNBLOCK: '차단 해제',
				USERNAME: '닉네임',
				USERNAME_DUPLICATED: '이미 사용중인 닉네임 입니다. (2~15자 이내의 영문,숫자,_)',
				USERNAME_INVALID: '닉네임은 15자 이내의 영문,숫자,_로 입력해 주세요.',
				USERNAME_REQUIRED: '닉네임을 입력해 주세요. (2~15자 이내의 영문,숫자,_)',
				WELCOME: '{{nickname}}님, 환영합니다!<br>푸딩.투를 함께 즐길 친구들을 찾아보세요!',
				WRITE_COMMENT: '댓글 작성',
				YOU: 'You!'
			},
			'ja': {
				AGREE_TERMS: '利用規約に同意',
				ALL: '全て',
				FACEBOOK_VERIFIED: 'Facebook認證に成功しました。',
				BACK_TO_TOP: 'TOPへ',
				BAN: 'おすすめキャンセル',
				BLOCK: 'ブロック',
				CONFIRM_BAN_USER: 'このユーザのおすすめ表示をやめますか？',
				CONNECT: '連結',
				DISCONNECT_FB: 'Facebookアカウントの連結を解除しますか？',
				DISCONNECT_TW: 'Twitterアカウントの連結を解除しますか？',
				DONE: '完了',
				EMAIL: 'Eメール',
				EMAIL_CONFIRM: [
						'{{email}}\n',
						'ご利用になるEメールのアドレスを確認してください。\n',
						'Eメールアドレスはログインアカウントで利用になり、\n',
						'パスワードの紛失の場合には入力した\n',
						'Eメールアドレスへ案内Eメールが転送されます。\n', 
						'このEメールで会員登録をしますか?'
					].join(''),
				EMAIL_DUPLICATED: 'すでに使用中のEメールです。',
				EMAIL_INVALID: '正確なEメールアドレスを入力してください。',
				EMAIL_REQUIRED: 'Eメールアドレスを入力してください。',
				EMOTIONS: ['ハッピー', 'ウキウキ', 'さびしい', 'シクシク', 'トキメキ', '日常の', '考え中', 'oh~!', 'サイコー!!', 'ペコペコ', '旅の思い出', '特別な日', '自分撮り', 'Pet Lover', 'Photo by'],
				ENTER_EMAIL: '会員登録時のEメール情報を入力してください。',
				ENTER_NICKNAME: '会員登録時のニックネームや名前を入力してください。',
				FILL_EMAIL: 'abc@abc.com',
				FILL_FIELDS: '入力された情報がありません。',
				FILL_PASSWORD: '6文字以上入力',
				FILL_PASSWORD_CONFIRMATION: 'パスワード再入力',
				FILL_PASSWORD_LOGIN: 'パスワードを入力してください。',
				FILL_USERNAME: '2~15文字の英・数字',
				FIND_FRIENDS: '友達を探して見ましょう。',
				FIND_FRIENDS_BUTTON: '友達を探す',
				FOLLOW: 'フォロー',
				FOLLOWER_SKYROCKETING: 'フォローが急上昇中のユーザ!',
				FOLLOWING: 'フォロー中',
				FOLLOW_REQUESTED: 'リクエスト済 ',
				FORGOT_EMAIL: 'Eメールを探す',
				FORGOT_PASSWORD: 'パスワードを探す',
				FRIENDS_IN_PUDDING: 'pudding.toを利用中の友たち',
				FRIENDS_MAYKNOW_TITLE: '友たちを探してみましょう。',
				HELP_ABOUT: 'ヘルプデスク',
				HELP_APPS: 'puddingシリーズのアプリを見る',
				HELP_PUDDING_CAMERA: 'pudding camera',
				HELP_PUDDING_FACE: '韓流スターマッチング',
				HELP_BLOG: 'pudding.to ブログ',
				HELP_TERMS: '利用規約',
				HELP_PRIVACY: '個人情報の保護について',
				INVITE: '招待',
				INVITE_FRIENDS: '友達を招待',
				INVITED: '招待完了',
				LINK_MUTUAL_FRIENDS: '<a href="/" data-link="mutual-friends">一緒に知っている友人 <em>{{count}}</em>名</a>',
				LOADING: '読み込み',
				LOADING_FRIENDS: '友たちを読み込み中',
				LOGIN: 'ログイン',
				LOGIN_WITH_FACEBOOK: 'Facebookからログイン',
				MAYKNOW_ALL_FOLLOWED: '知り合いの友達と全員フォローしました。<br><br><strong>おすすめユーザから</strong>新たな友達に出会う機会を<br>見逃さないでください。',
				MUTUAL_FRIEND_HEADER: '{{name}} さんと一緒に知っている友人 {{count}}名',
				NICKNAME_OR_NAME: 'ニックネームや名前',
				NONE_BLOCKS: 'ブロックしたユーザはいません。',
				NONE_FEED_MY: 'ニュースがありません。<br>投稿した写真に関する新たないいね！やコメント情報を<br>表示します。',
				NONE_FEED_FOLLOWER: 'フォロー中のニュースがありません。<br>フォロー中に関する新たなニュースを<br>表示します。',
				NONE_FOLLOWS: '現在フォロワーがいません。',
				NONE_FOLLOWINGS: '現在フォロー中のユーザがいません。',
				NONE_FRIENDS: '友たちがいません。',
				NONE_FRIENDS_TO_INVITE: '招待する友達がいません。',
				NONE_LOCATIONS_MINE: '場所タグがありません。<br>写真登録の時に場所を入れてみましょう',
				NONE_LOCATIONS_OTHERS: '場所タグがありません。',
				NONE_MAYKNOW_1: 'Facebook、Twitterとの連結や<br>pudding.toで友人をフォローすると<br>お互いに知り合いの友たちを出会うことができます。',
				NONE_MAYKNOW_2: '知り合いの友たちがいなくても大丈夫!<br><br>Facebook、Twitterとの連結や<br>pudding.toでフォローを重ねることで<br>毎日新たな友達を出会うチャンスも増えます。',
				NONE_MUSICS_MINE: '音楽タグがありません。<br>写真登録の時に音楽を入れてみましょう。',
				NONE_MUSICS_OTHERS: '音楽タグがありません。',
				NONE_POPULAR_PHOTOS: '人気写真がありません。',
				NONE_SUGGESTED_FRIENDS: '<p class="cn3">条件に当てはまる推薦友達がいません.</p>',
				NONE_SUGGESTED_SIMILAR_FRIENDS: '<p class="cn3">写真と共にタグ、音楽、場所などの情報を一緒に登録すると、毎日同じ好みを持つ友達を紹介してくれます。</p>',
				NONE_TAGS_MINE: '#タグがありません。<br>写真登録の時に#タグを入力してみましょう。',
				NONE_TAGS_OTHERS: '#タグがありません。',
				NONE_USER: '‘{{name}}’ ニックネームや名前を持つ<br>ユーザがいません。',
				PASSWORD: 'パスワード',
				PASSWORD_INVALID: 'パスワードを6文字以上に入力してください。',
				PASSWORD_REQUIRED: 'パスワードを入力してください。(6文字以上)',
				PASSWORD_CONFIRMATION: 'パスワード確認',
				PASSWORD_CONFIRMATION_REQUIRED: 'パスワードを再入力してください。',
				PASSWORD_CONFIRMATION_INVALID: 'パスワードが一致しませんでした。',
				PHOTO_UNIT: '{{count}} 枚',
				PHOTOS_UNIT: '{{count}} 枚',
				POPULAR_PHOTO: '人気写真に選定されました！',
				PRIVACY_POLICY: '個人情報の保護',
				REPORT: '申告する',
				REPORT_SUCCEEDED: '申告完了しました。早く検討し処理します。',
				SEARCH_FRIENDS: '友人を探す',
				SEARCH_FRIENDS_DIRECTLY: 'ニックネームと名前から探す',
				SEARCH_RESULT: '検索結果',
				SEE_MORE: 'もっと見る',
				SELECT: '選択',
				SENT_FORGOT_PASSWORD: '{{email}}でパスワードの再設定に関するリンクを転送しました。',
				SERVER_ERROR: '情報の読み込みに失敗しました。再び試してください。',
				SHOW_TERMS: '<a href="#terms-service">利用規約/個人情報取り扱い</a> 同意',
				SIGNUP: '会員登録',
				SIGNUP_WITH_FACEBOOK: 'Facebookから会員登録',
				SIGNUP_WITH_ANOTHER_EMAIL: 'ほかのEメールで会員登録',
				SUGGESTED_FRIENDS: 'タグ、音楽、場所が似通うユーザや人気ユーザ',
				SUGGESTED_FIRST_FRIENDS: '推薦友達と一緒にpudding.toを始めてみませんか?',
				SNS_DESC: '共有設定をするとpudding.toに投稿した写真がTwitter、Facebookにも自動的に投稿ができます。',
				TERM_REQUIRED: '利用規約/個人情報取り扱い\n同意にチェックしてください。',
				TERMS_OF_SERVICE: '利用規約',
				TIME_JUST_NOW: 'すぐ前',
				TIME_SECOND_AGO: '秒前',
				TIME_SECONDS_AGO: '秒前',
				TIME_MINUTE_AGO: '分前',
				TIME_MINUTES_AGO: '分前',
				TIME_HOUR_AGO: '時間前',
				TIME_HOURS_AGO: '時間前',
				TIME_DAY_AGO: '日前',
				TIME_DAYS_AGO: '日前',
				TIME_WEEK_AGO: '週前',
				TIME_WEEKS_AGO: '週前',
				TIME_MONTH_AGO: 'ヶ月前',
				TIME_MONTHS_AGO: 'ヶ月前',
				TIME_YEAR: '年',
				TIME_YEARS: '年',
				UNBLOCK: 'ブロック解除',
				USERNAME: 'ユーザ名 ',
				USERNAME_DUPLICATED: 'すでに利用中のニックネームです。(2~15文字以内の英語、数字、_)',
				USERNAME_INVALID: 'ニックネームは15文字以内の英語、数字、_で入力してください。',
				USERNAME_REQUIRED: 'ニックネームを入力してください。(2~15文字以内の英語、数字、_)',
				WELCOME: '{{nickname}}さん!　pudding.toの世界へようこそ！<br>pudding.toで新たな友人を探してみましょう。',
				WRITE_COMMENT: 'コメント',
				YOU: 'You!'
			},
			'zh': {
				AGREE_TERMS: '同意条款',
				ALL: '全部',
				FACEBOOK_VERIFIED: 'facebook身份认证成功.',
				BACK_TO_TOP: '返回首页',
				BAN: '忽略推荐',
				BLOCK: '屏蔽',
				CONFIRM_BAN_USER: '不再接受对该用户的推荐吗?',
				CONNECT: '链接',
				DISCONNECT_FB: '解除与facebook帐户的链接吗?',
				DISCONNECT_TW: '解除与twitter帐户的链接吗?',
				DONE: '完成',
				EMAIL: '电子邮件',
				EMAIL_CONFIRM: [
						'{{email}}\n',
						'用户的电子邮件地址准确\n',
						'请确认.\n',
						'作为登录帐户使用,\n',
						'丢失密码的情况\n',
						'邮件将发送到输入的地址.\n',
						'要用上面的地址来注册吗?'
					].join(''),
				EMAIL_DUPLICATED: '已经在使用的邮箱',
				EMAIL_INVALID: '请输入正确的电子邮件.',
				EMAIL_REQUIRED: '请输入电子邮件.',
				EMOTIONS: ['好心情', '兴高采烈', '孤独', '感人', '噗嗵噗嗵', '日常的', '沉思', 'oh~!', '太棒了!', '嗯~美味', '旅行中', '特别的日子', '自拍', 'Pet Lover', 'Photo by'],
				ENTER_EMAIL: '请输入注册时输入的电子邮件.',
				ENTER_NICKNAME: '请输入注册的昵称或姓名.',
				FILL_EMAIL: 'abc@abc.com',
				FILL_FIELDS: '没有输入的信息.',
				FILL_PASSWORD: '输入6个字符以上',
				FILL_PASSWORD_CONFIRMATION: '再次输入密码',
				FILL_PASSWORD_LOGIN: '请输入密码.',
				FILL_USERNAME: '2~15个字符的英文,数字',
				FIND_FRIENDS: '试着搜寻一下朋友!',
				FIND_FRIENDS_BUTTON: '搜寻朋友',
				FOLLOW: '关注',
				FOLLOWER_SKYROCKETING: '关注者急速上升的朋友!',
				FOLLOWING: '粉丝',
				FOLLOW_REQUESTED: '要求', 
				FORGOT_EMAIL: '找回电子邮件',
				FORGOT_PASSWORD: '找回密码',
				FRIENDS_IN_PUDDING: '使用布丁.II的朋友',
				FRIENDS_MAYKNOW_TITLE: '试着搜寻一下朋友',
				HELP_ABOUT: '帮助/客户中心',
				HELP_APPS: '查看布丁的其他应用程序',
				HELP_PUDDING_CAMERA: '布丁相机',
				HELP_PUDDING_FACE: '布丁脸部识别',
				HELP_BLOG: '布丁.II博客',
				HELP_TERMS: '服务条款',
				HELP_PRIVACY: '个人信息隐私政策',
				INVITE: '邀请',
				INVITE_FRIENDS: '邀请其他朋友',
				INVITED: '邀请完成',
				LINK_MUTUAL_FRIENDS: '<a href="/" data-link="mutual-friends">共同的朋友 <em>{{count}}</em>名</a>',
				LOADING: '加载中',
				LOADING_FRIENDS: '正在打开朋友信息.',
				LOGIN: '登录',
				LOGIN_WITH_FACEBOOK: '用facebook登录',
				MAYKNOW_ALL_FOLLOWED: '您认识的人已经都关注过了.<br><br><strong>在推荐朋友里</strong>找一下与我适合的朋友!',
				MUTUAL_FRIEND_HEADER: '和{{name}} 共同的朋友 {{count}}名',
				NICKNAME_OR_NAME: '昵称,姓名',
				NONE_BLOCKS: '没有被屏蔽的用户.',
				NONE_FEED_MY: '没有新的消息.<br>通知赞我的照片及<br>评论更新的消息.',
				NONE_FEED_FOLLOWER: '没有粉丝的消息.<br>通知我的粉丝的<br>最新消息.',
				NONE_FOLLOWS: '关注者一名都没有.',
				NONE_FOLLOWINGS: '粉丝一名都没有.',
				NONE_FRIENDS: '没有朋友.',
				NONE_FRIENDS_TO_INVITE: '没有要邀请的朋友.',
				NONE_LOCATIONS_MINE: '没有地点标注.<br>上传照片时, 尝试放上地点.',
				NONE_LOCATIONS_OTHERS: '没有地点标注.',
				NONE_MAYKNOW_1: '连接facebook, twitter或者在<br>布丁.II会有更多的关注<br>将会见到更多你认识的人.',
				NONE_MAYKNOW_2: '没有认识的朋友请不要失望.<br><br>连接facebook, twitter或者<br>在布丁.II会有更多的关注<br>每天为您找高兴见到的朋友.',
				NONE_MUSICS_MINE: '没有音乐标注.<br>上传照片时, 尝试放上音乐.',
				NONE_MUSICS_OTHERS: '没有音乐标注.',
				NONE_POPULAR_PHOTOS: '没有热门照片.',
				NONE_SUGGESTED_FRIENDS: '<p class="cn3">没有推荐的朋友.</p>',
				NONE_SUGGESTED_SIMILAR_FRIENDS: '<p class="cn3">照片和标注, 音乐, 地点信息放在一起<br> 可以见到趣向相近的朋友!</p>',
				NONE_TAGS_MINE: '#没有标注.<br>上传照片时, #尝试输入标签.',
				NONE_TAGS_OTHERS: '#没有标注.',
				NONE_USER: '‘{{name}}’ 昵称或姓名<br>没有人.',
				PASSWORD: '密码',
				PASSWORD_INVALID: '密码请输入六个字符以上.',
				PASSWORD_REQUIRED: '请输入密码. (6个字符以上)',
				PASSWORD_CONFIRMATION: '确认密码',
				PASSWORD_CONFIRMATION_REQUIRED: '请再次输入密码.',
				PASSWORD_CONFIRMATION_INVALID: '密码不匹配.',
				PHOTO_UNIT: '{{count}} 张',
				PHOTOS_UNIT: '{{count}} 张',
				POPULAR_PHOTO: '被选定为最热门的照片~!',
				PRIVACY_POLICY: '个人信息隐私政策',
				REPORT: '申报',
				REPORT_SUCCEEDED: '已收到申报. 将尽快查看并处理好.',
				SEARCH_FRIENDS: '搜寻朋友',
				SEARCH_FRIENDS_DIRECTLY: '直接查找 (昵称, 姓名)',
				SEARCH_RESULT: '搜索结果',
				SEE_MORE: '更多',
				SELECT: '选择',
				SENT_FORGOT_PASSWORD: '往{{email}}发送了一个链接来重新设置密码.',
				SERVER_ERROR: '没有打开的信息. 请稍后再试.',
				SHOW_TERMS: '<a href="#terms-service">条款/私人信息办理方针</a> 同意',
				SIGNUP: '报名',
				SIGNUP_WITH_FACEBOOK: '用facebook注册布丁',
				SIGNUP_WITH_ANOTHER_EMAIL: '用其他电子邮件注册',
				SUGGESTED_FRIENDS: '标注,音乐,地点相同或人气高的朋友',
				SUGGESTED_FIRST_FRIENDS: '开始关注推荐朋友，好好享受布丁.II吧!',
				SNS_DESC: '链接设置后在布丁.II上传的照片twitter,facebook都可同时看到.',
				TERM_REQUIRED: '条款//私人信息办理方针\n请选择同意.',
				TERMS_OF_SERVICE: '服务条款',
				TIME_JUST_NOW: '一会前',
				TIME_SECOND_AGO: '秒前',
				TIME_SECONDS_AGO: '秒前',
				TIME_MINUTE_AGO: '分钟前',
				TIME_MINUTES_AGO: '分钟前',
				TIME_HOUR_AGO: '小时前',
				TIME_HOURS_AGO: '小时前',
				TIME_DAY_AGO: '天前',
				TIME_DAYS_AGO: '天前',
				TIME_WEEK_AGO: '周前',
				TIME_WEEKS_AGO: '周前',
				TIME_MONTH_AGO: '个月前',
				TIME_MONTHS_AGO: '个月前',
				TIME_YEAR: '年',
				TIME_YEARS: '年',
				UNBLOCK: '解除屏蔽',
				USERNAME: '昵称',
				USERNAME_DUPLICATED: '此昵称已被使用. (2~15个字符以内的英文,数字,_)',
				USERNAME_INVALID: '昵称请输入15个字符以内的英文、数字、_.',
				USERNAME_REQUIRED: '请输入昵称. (2~15个字符以内的英文,数字,_)',
				WELCOME: '{{nickname}}欢迎您!<br>寻找一起享受布丁.II的朋友们吧!',
				WRITE_COMMENT: '发表评论',
				YOU: 'You!'
			}
		};
	
	/**
	 * @constructor
	 * @ignore
	 */
	i18n = function i18n(options) {
		if (_INSTANCE) {
			return _INSTANCE;
		} else if (!(this instanceof i18n)) {
			return (_INSTANCE = new i18n(options));
		} else {
			_INSTANCE = this;
		}
		this._init(options);
	};
	i18n.prototype = /** @lends kth.puddingto.i18n.prototype */ {
		options: {
			defaultLocale: _LOCALE.ENGLISH,
			locale: '',
			exportTo: null,
			queryVariable: 'locale'
		},
		
		_locale: '',

		_init: function(options) {
			var options = this.options = $.extend(this.options, options);
			this.setLocale(options.locale);
		},
		
		_isAvailableLocale: function(locale) {
			var prop;
			for (prop in _LOCALE) {
				if (_LOCALE[prop] === locale) {
					return true;
				}
			}
			return false;
		},
		
		_getLocaleFromApp: function() {
			var localeFromQueryString = kth.getQueryVariable(this.options.queryVariable);
			return localeFromQueryString && localeFromQueryString.substr(0, 2);
		},
		
		_getLocaleFromNavigator: function() {
			var locale;
			
			if ($.os.android) {
				if (navigator.userAgent.indexOf('ko-kr') > -1) {
					locale = _LOCALE.KOREAN;	
				} else if (navigator.userAgent.indexOf('ja-jp') > -1) {
					locale = _LOCALE.JAPANESE;
				} else if (navigator.userAgent.indexOf('zh') > -1) {
					locale = _LOCALE.CHINESE;
				}
			} else {
				locale = {
					'ko': _LOCALE.KOREAN,
					'ja': _LOCALE.JAPANESE,
					'zh': _LOCALE.CHINESE
				}[navigator.language.substr(0, 2)];
			}
			return locale;
		},
		
		_importAdditionalStyleSheet: function(locale) {
			var link = null,
				styleSheetHref = '';
				
			if (_STYLESHEET.AVAILABLE_LOCALES.indexOf(locale) > -1) {
				link = $('link');
				styleSheetHref = link.attr('href').split('.css')[0] + '_' + locale + '.css';
				
				link.after(Mustache.to_html(_STYLESHEET.LINK, {
					href: styleSheetHref
				}));
			}
		},
		
		_exportLocaleInfo: function(locale) {
			var exportTo = this.options.exportTo;
			if (exportTo) {
				exportTo.locale = locale;
				exportTo.i18n = _MESSAGES[locale];
			}
			return exportTo;
		},
		
		setLocale: function(locale) {
			locale = locale || this._getLocaleFromApp() || this._getLocaleFromNavigator();
			
			this._locale = this._isAvailableLocale(locale) ? locale : this.options.defaultLocale;
			this._importAdditionalStyleSheet(this._locale);
			this._exportLocaleInfo(this._locale);
			
			return this._locale;
		},
		
		getLocale: function() {
			return this._locale;
		},
		
		getMessage: function(key) {
			return _MESSAGES[this.getLocale()][key];
		}
	};
	return i18n;
})('kth.puddingto.i18n'))({
	exportTo: PuddingTo,
	locale: ''
});

})(window);