/**
 * @fileOverview
 * @name kth.puddingto.profileTag.js
 * @author Kim il (blaxtar@kthcorp.com)
 * @version 20121127
 * @lastModified 2012-11-27
 * @created 2012-11-26
 * @description
 * <pre>
 * Pudding.to > Profile > Tag
 *
 * classes:
 * - {@link kth.puddingto.Tag} Tag List
 * 
 * </pre>
 */
/*jslint browser:true, devel:true, white:false, nomen: true, plusplus:false, sloppy:true */
(function(global, $) {

/**
 * Tag List
 * @class Tag List
 * @name kth.puddingto.Tag
 * @param {object} options Options
 * @example
kth.puddingto.Tag();
 */
kth.getPackage('kth.puddingto.Tag', (function(NAME) {
	var /* private static constants */
		_INSTANCE = null;

	/**
	 * @constructor
	 * @ignore
	 */
	function Tag(options) {
		if (_INSTANCE) {
			return _INSTANCE;
		} else if (!(this instanceof Tag)) {
			return (_INSTANCE = new Tag(options));
		} else {
			_INSTANCE = this;
		}
		this._initialize(options);
	}
	Tag.prototype = /** @lends kth.puddingto.Tag.prototype */ {
		_initialize: function() {
			var mine = PuddingTo.params.user_id == PuddingTo.params.owner_id;
			
			$('#p2-tag-text').text(PuddingTo.params.tag_str);
			$('#page-tags .p2-none-text p').data('i18n', 'none-tags-' + (mine ? 'mine' : 'others'));
			$('#page-musics	.p2-none-text p').data('i18n', 'none-musics-' + (mine ? 'mine' : 'others'));
			$('#page-locations .p2-none-text p').data('i18n', 'none-locations-' + (mine ? 'mine' : 'others'));

			$('.tgMu').on('click', 'a', this._onTabClick);
			$('[data-list]').on('click', 'li a', this._onItemClick);
			
			this._displayCount();
		},
		
		_displayCount: function() {
			PuddingTo.API.call('get user/tags/count', {
				success: function(data) {
					console.log(data);
					$('[href^="#"]').each(function(index, element) {
						var $element = $(element),
							$counter = $element.find('span'),
							count = data[{
								'#page-tags': 'tag',
								'#page-musics': 'music',
								'#page-locations': 'location'
							}[$element.attr('href')]];
						
						$counter.text(count);
					});
				}
			});
		},
		
		_onTabClick: function(event) {
			event.preventDefault();

			var $this = $(this),
				$item = $this.closest('li'),
				href;

			// 현재 활성화된 탭이면 진행하지 않는다.
			if ($item.hasClass('on')) {
				return;
			}

			$('.tgMu .on').removeClass('on');
			$('.tgLst.on').removeClass('on');

			$item.addClass('on');
			
			href = $this.attr('href');
			$(href).addClass('on');
		},
		
		_onItemClick: function(event) {
			event.preventDefault();
			
			var $this = $(this),
				container = $this.closest('[data-list]'),
				type = {
					'page-tags' : 'tag',
					'page-musics' : 'music',
					'page-locations' : 'poi'
				}[container.attr('id')],
				params = {
					type : type,
					title: encodeURIComponent($this.text())
				},
				url;
				
			if (type == 'poi') {
				params.poi = $this.closestData('id');
			}

			url = Mustache.to_html(PuddingTo.consts.CALL_TAG, params);
			console.log(url);
			location.href = url;
		}
	};
	return Tag;
}('kth.puddingto.Tag')))();

}(window, Zepto));