/**
 * @fileOverview
 * @name kth.puddingto.templates.js
 * @author Kim il (blaxtar@kthcorp.com)
 * @version 20121114
 * @lastModified 2012-11-14
 * @created 2012-07-09
 * @description
 * <pre>
 * Pudding.to > Templates
 *
 * classes:
 * - {@link kth.puddingto.Templates} 템플릿 모듈
 * </pre>
 */
/*jslint browser:true, devel:true, white:false, nomen: true, plusplus:false, sloppy:true */
(function(global, $) {

/**
 * 템플릿 모듈을 생성한다
 * @class 템플릿 모듈
 * @name kth.puddingto.Templates
 * @param {object} options Options
 * @example
kth.puddingto.Templates({
	exportTo: PuddingTo
});
 */
kth.getPackage('kth.puddingto.Templates', (function(NAME, Templates) {
	var /* external references */
		i18n = kth.puddingto.i18n(),
		
		/* private static constants */
		_INSTANCE = null,
		_TEMPLATES = {
			// 차단하기
			'user/blocks': {
				text: [
					'<li data-user-id="{{id}}">',
						'<div class="im">',
							'<a href="/" data-link="profile">',
								'<img src="{{profile_picture}}" alt="">',
							'</a>',
						'</div>',
						'<div class="cn">',
							'<strong>',
								'<a href="/" data-link="profile">{{username}}</a>',
							'</strong>',
							'<span>{{realname}}</span>',
						'</div>',
						'<div class="bn1">',
							'<a href="/" class="ubk" data-link="unblock">',
								'<span>{{unblockText}}</span>',
							'</a>',
						'</div>',
					'</li>'
				].join(''),
				
				render: function(item) {
					var extra = {
						unblockText: i18n.getMessage('UNBLOCK')
					};
	
					return $.extend(item, extra);
				}
			},
			
			// 아는 친구
			'user/familiar': {
				text: [
					'<li data-user-id="{{id}}">',
						'<div class="im">',
							'<a href="/" data-link="profile">',
								'<img src="{{profile_picture}}" alt="">',
							'</a>',
						'</div>',
						'<div class="cn">',
							'<div class="sp">',
								'<strong>',
									'<a href="/" data-link="profile">{{username}}</a>',
								'</strong>',
								'<span>{{realname}}</span>',
							'</div>',
							'<p class="{{iconClass}}">{{{mutualFriendsText}}}</p>',
						'</div>',
						'<div class="bn2">',
							'<strong class="ldg">',
								'<a href="/" class="add" data-link="follow">',
									'<span>{{followingText}}</span>',
								'</a>',
							'</strong>',
							'<a href="/" class="ban" data-link="ban">',
								'<span>Delete</span>',
							'</a>',
						'</div>',
					'</li>'
				].join(''),
				
				render: function(item) {
					var following	 = !!item.follow,
						recommend	 = item.recommend,
						recommendType = recommend.recomm_type,
						extra		 = {
							followingText: i18n.getMessage('FOLLOW')
						};
			  
					if (recommendType == '01') {
						extra.iconClass = 'icn3';
						extra.mutualFriendsText  = recommend.username;
					} else if (recommendType == '02') {
						extra.iconClass = 'icn2';
						extra.mutualFriendsText  = recommend.username;
					} else if (recommendType == '11') {
						extra.iconClass = 'icn1';
						extra.mutualFriendsText  = Mustache.to_html(i18n.getMessage('LINK_MUTUAL_FRIENDS'), {count: item.recommend.recomm_count});
					}
	
					return $.extend(item, extra);
				}
			},
			
			// 함께 아는 친구
			'user/familiar/with': {
				text: [
					'<li data-user-id="{{id}}">',
						'<a href="/" data-link="profile">',
							'<img src="{{profile_picture}}" alt="">',
							'<strong>{{username}}</strong>',
							'<span>{{realname}}</span>',
						'</a>',
					'</li>'
				].join(''),
				
				render: function(item) {
					var following = !!item.follow,
						extra	 = {
							followingText: i18n.getMessage('FOLLOW')
						};
	
					return $.extend(item, extra);
				}
			},
			
			// 새소식
			'user/feed': {
				text: [
					'<li class="ty1 {{classText}}" data-user-id="{{activity_uid}}" data-photo-id="{{post_id}}">',
						'<a href="/" data-link="{{linkType}}">',
							'<div class="im">',
								'<img src="{{profile_picture}}" alt="">',
							'</div>',
							'<div class="cn">',
								'<p>{{{activity}}}</p>',
								'<span>{{activity_time}}</span>',
							'</div>',
							'{{#post_id}}',
								'<div class="tm">',
									'<img src="{{photo_link}}" alt="">',
								'</div>',
							'{{/post_id}}',
						'</a>',
					'</li>'
				].join(''),
				
				render: function(item) {
					var extra = {};
					
					if (feedType == 'my' && item.feed_id > lastFeedId) {
						extra.classText = 'pNew';
					}
	
					if (parseInt(item.activity_uid, 10)) {
						extra.linkType = 'profile';
					}
	
					if (parseInt(item.post_id, 10)) {
						extra.linkType = 'photo';
					}
	
					extra.activity = item.activity.replace(/\[(.+?)\]/g, function(source, name) {
						if (name == item.activity_user_name) {
							return '<strong>' + name + '</strong>';
						} else if (name == item.to_user_name) {
							return '<strong>' + name + '</strong>';
						} else {
							return name;
						}
					});
	
					if (item.activity_desc) {
						extra.activity += ' "' + item.activity_desc + '"';
					}
					
					extra.activity_time = PuddingTo.formatTime(item.activity_time);
	
					return $.extend(item, extra);
				}
			},
			
			// 팔로우
			'user/follows': {
				text: [
					'<li data-user-id="{{id}}">',
						'<div class="im">',
							'<a href="/" data-link="profile">',
								'<img src="{{profile_picture}}" alt="">',
							'</a>',
						'</div>',
						'<div class="cn">',
							'<strong>',
								'{{#emotion}}',
									'<em>{{emotionText}}</em>',
								'{{/emotion}}',
								'<a href="/" data-link="profile">{{username}}</a>',
							'</strong>',
							'<span>{{realname}}</span>',
						'</div>',
						'<div class="bn1">',
							'<strong class="ldg">',
								'{{^mine}}',
									'<a href="/" class="{{followingClass}}" data-link="follow">',
								'{{/mine}}',
									'<span',
										'{{#mine}}',
											' class="you"',
										'{{/mine}}',
									'>',
										'{{followingText}}',
									'</span>',
								'{{^mine}}',
									'</a>',
								'{{/mine}}',
							'</strong>',
						'</div>',
					'</li>'
				].join(''),
				
				render: function(item) {
					var mine = item.id == PuddingTo.params.user_id,
						following = !!item.follow,
						extra = {
							emotionText : item.emotion ? i18n.getMessage('EMOTIONS')[item.emotion - 1] : '',
							following : following,
							followingClass: following ? 'ing' : 'add',
							followingText : i18n.getMessage(mine ? 'YOU' : (following ? 'FOLLOWING' : 'FOLLOW')),
							mine : mine
						};
				
					return $.extend(item, extra);
				}
			},
			
			// 친구찾기 결과
			'user/search/email': {
				text: [
					'<li data-user-id="{{id}}">',
						'<a href="/" data-link="email-detail">',
							'<img src="{{profile_picture}}" alt="">',
							'<strong>{{username}}</strong>',
							'<span>{{realname}}</span>',
						'</a>',
					'</li>'
				].join('')
			},
			
			'user/general': {
				text: [
					'<li data-user-id="{{id}}">',
						'<div class="im">',
							'<a href="/" data-link="profile">',
								'<img src="{{profile_picture}}" alt="">',
							'</a>',
						'</div>',
						'<div class="cn">',
							'<strong>',
								'<a href="/" data-link="profile">{{username}}</a>',
							'</strong>',
							'<span>{{realname}}</span>',
						'</div>',
						'<div class="bn1">',
							'<strong class="ldg">',
								'{{^mine}}{{^followRequested}}',
									'<a href="/" class="{{followingClass}}" data-link="follow">',
								'{{/followRequested}}{{/mine}}',
								'<span',
									'{{#mine}}',
										' class="you"',
									'{{/mine}}',
									'{{#followRequested}}',
										' class="{{followingClass}}"',
									'{{/followRequested}}',
								'>',
									'{{followingText}}',
								'</span>',
								'{{^mine}}{{^followRequested}}',
									'</a>',
								'{{/followRequested}}{{/mine}}',
							'</strong>',
						'</div>',
					'</li>'
				].join(''),
	
				render: function(item) {
					var mine	  = item.id == PuddingTo.params.user_id,
						following = item.follow,
						extra	 = {
							mine		  : mine,
							followRequested: item.follow === 2, // response[index].follow 값이 2일 경우 비공개 사용자 팔로우 신청중
							followingClass: ({
								0: 'add',
								1: 'ing',
								2: 'req'
							})[following],
							followingText : i18n.getMessage(mine ? 'YOU' : (({
								0: 'FOLLOW',
								1: 'FOLLOWING',
								2: 'FOLLOW_REQUESTED'
							})[following]))
						};
	
					return $.extend(item, extra);
				}
			},
			
			// 초대하기
			'user/invite': {
				text: [
					'<li data-user-id="{{id}}">',
						'<div class="im">',
							'<a href="/" data-link="profile">',
								'<img src="{{profile_picture}}" alt="">',
							'</a>',
						'</div>',
						'<div class="cn">{{username}}</div>',
						'<div class="bn1">',
							'<strong class="ldg">',
								'<a href="/" class="inv" data-link="invite" data-site="{{site}}">',
									'<span>{{inviteText}}</span>',
								'</a>',
							'</strong>',
						'</div>',
					'</li>'
				].join(''),
				
				render: function(item) {
					var extra = {
							inviteText: i18n.getMessage('INVITE')
						};
	
					return $.extend(item, extra);
				}
			},
			
			// 추천친구
			/**
			 * @deprecated
			 */
			'user/suggest': {
				text: [
					'<li data-user-id="{{id}}" data-ga-label="{{ga_label}}">',
						'<div class="grp1">',
							'<div class="im">',
								'<a href="/" data-link="profile">',
									'<img src="{{profile_picture}}" alt="">',
								'</a>',
							'</div>',
							'<div class="cn">',
								'<strong>',
									'<a href="/" data-link="profile">{{username}}</a>',
								'</strong>',
								'<span>{{realname}}</span>',
							'</div>',
							'<div class="bn1">',
								'<strong class="ldg">',
									'<a href="/" class="add" data-link="follow">',
										'<span>{{followingText}}</span>',
									'</a>',
								'</strong>',
							'</div>',
						'</div>',
						'<div class="grp2">',
							'<p class="{{recommClass}}">',
								'<em class="{{tagClass}}">{{recommText}}</em>',
							'</p>',
							'<p class="nIm">',
								'{{#thumbnails}}',
									'<a href="/" data-link="photo" data-photo-id="{{photoId}}">',
										'<img src="{{photoUrl}}" alt="">',
									'</a>',
								'{{/thumbnails}}',
							'</p>',
						'</div>',
						'<span class="x">',
							'<a href="/" data-link="ban"></a>',
						'</span>',
					'</li>'
				].join(''),
				
				render: function(item) {
					var extra	 = {
							followingText: i18n.getMessage('FOLLOW'),
							thumbnails   : item.photos.map(function(photo) {
								return {
									photoId : photo.id,
									photoUrl: photo.thumbnail
								};
							})
						},
						recommType = item.recommend.recomm_type;
	
					if (recommType < '51') {	//공통 속성
						extra.recommClass = 'nTg';
						extra.recommText  = item.recommend.recomm_name;
						extra.ga_label = 'same_tag';
					} else {	//인기가 많은 친구들
						extra.recommClass = 'nUp';
						extra.ga_label = 'hot_user';
					}
					
					switch (recommType) {
						case '21':
							extra.tagClass = 'tg';
							break;
	
						case '22':
							extra.tagClass = 'mc';
							break;
	
						case '23':
							extra.tagClass = 'loc';
							break;
	
						case '51':  //팔로워가 급상승한 친구
							extra.recommText = i18n.getMessage('FOLLOWER_SKYROCKETING');
							break;
	
						case '52': //인기사진에 뽑혔어요?
							extra.recommText = i18n.getMessage('POPULAR_PHOTO');
							break;
					}
	
					return $.extend(item, extra);
				}
			},
			
			// 추천친구
			'suggestions/people': {
				text: [
					'<li data-user-id="{{id}}" data-ga-label="{{ga_label}}">',
						'<div class="grp1">',
							'<div class="im">',
								'<a href="/" data-link="profile">',
									'<img src="{{profile_picture}}" alt="">',
								'</a>',
							'</div>',
							'<div class="cn">',
								'<strong>',
									'<a href="/" data-link="profile">{{username}}</a>',
								'</strong>',
								'<span>{{realname}}</span>',
							'</div>',
							'<div class="bn1">',
								'<strong class="ldg">',
									'<a href="/" class="add" data-kms-message="{{kmsMessage}}" data-link="follow">',
										'<span>{{followingText}}</span>',
									'</a>',
								'</strong>',
							'</div>',
						'</div>',
						'<div class="grp2">',
							'<p class="nIm">',
								'{{#thumbnails}}',
									'<a href="/" data-link="photo" data-photo-id="{{photoId}}">',
										'<img src="{{photoUrl}}" alt="">',
									'</a>',
								'{{/thumbnails}}',
							'</p>',
						'</div>',
						'{{^isFirst}}',
							'<div class="grp3">',
								'{{#isSimilar}}',
									'<p class="nTg">',
										'<em class="{{tagClass}}">{{recommText}}</em>',
									'</p>',
								'{{/isSimilar}}',
								'<span class="x">',
									'<a href="/" data-link="ban"></a>',
								'</span>',
							'</div>',
						'{{/isFirst}}',
					'</li>'
				].join(''),
				
				render: function(item, options) {
					var extra	 = $.extend({
							followingText: i18n.getMessage('FOLLOW'),
							thumbnails   : item.photos.map(function(photo) {
								return {
									photoId : photo.id,
									photoUrl: photo.thumbnail
								};
							}).slice(0, 4),
							isFirst: options.suggestion_type === "first",
							isSimilar: options.suggestion_type === "similar",
							kmsMessage: ({
								'samezone': 'Suggested_Area_Follow',
								'hot': 'Suggested_Popular_Follow',
								'profileChanged': 'Suggested_Profile_Follow',
								'similar': 'Suggested_Tag_Follow',
								'first': 'Started_Follow'
							})[options.suggestion_type]
						}, options),
						recommType = item.recommend && item.recommend.recomm_type;
						
					if (recommType) {
						extra.recommText  = item.recommend.recomm_name;
						switch (recommType) {
							case '21':
								extra.tagClass = 'tg';
								break;
		
							case '22':
								extra.tagClass = 'mc';
								break;
		
							case '23':
								extra.tagClass = 'loc';
								break;
						}
					}				
	
					return $.extend(item, extra);
				}
			},
			
			// 프로필 태그
			'user/tags': {
				text: [
					'<li data-id="{{id}}">',
						'<a href="/">{{tag}}</a>',
						'<span>{{count}}</span>',
					'</li>'
				].join(''),
				
				render: function(item) {
					var count = item.photos_count,
						extra = {
						count: Mustache.to_html(i18n.getMessage(count > 1 ? 'PHOTOS_UNIT' : 'PHOTO_UNIT'), {count: count}),
						tag  : item.tag || item.poi
					};
	
					return $.extend(item, extra);
				}
			},
	
			// 위치 검색
			'photo/location/search': {
				text: [
					'<li data-location-id="{{id}}" data-location-name="{{name}}" data-location-latitude="{{latitude}}" data-location-longitude="{{longitude}}">',
						'<a class="tx" href="/" data-link="location">',
							'<strong>{{name}}</strong>',
							'<span>{{address}}</span>',
						'</a>',
						'{{#selectButton}}',
							'<a class="bn" href="#" data-link="location-select">{{selectButton}}</a>',
						'{{/selectButton}}',
					'</li>'
				].join(''),
				
				render: (function() {
					var SELECT_BUTTON = $('[data-list-has-select]').length ? i18n.getMessage('SELECT') : undefined;
					
					return SELECT_BUTTON ? function(item) {
						return $.extend(item, {
							selectButton: SELECT_BUTTON
						});
					} : undefined;
				}())
			},
			
			// 인기사진
			'photo/popular': {
				text: [
					'<li data-photo-id="{{id}}">',
						'<a href="/" data-link="photo">',
							'<img src="{{image_url}}" alt="">',
						'</a>',
					'</li>'
				].join('')
			}
		};
	
	/**
	 * @constructor
	 * @ignore
	 */
	Templates = function Templates(options) {
		if (_INSTANCE) {
			return _INSTANCE;
		} else if (!(this instanceof Templates)) {
			return (_INSTANCE = new Templates(options));
		} else {
			_INSTANCE = this;
		}
		this._init(options);
	};
	Templates.prototype = /** @lends kth.puddingto.Templates.prototype */ {
		/**
		 * 옵션 객체
		 */
		options: {
			exportTo: null
		},

		_init: function(options) {
			var options = this.options = $.extend(this.options, options);
			this._exportTemplates();
		},
		
		_exportTemplates: function() {
			var exportTo = this.options.exportTo;
			if (exportTo) {
				exportTo.templates = _TEMPLATES;
			}
			return exportTo;
		},
		
		/**
		 * 템플릿 객체를 반환
		 * @param {string} key 템플릿 객체의 키
		 */
		getTemplate: function(key) {
			return _TEMPLATES[key];
		},
		
		/**
		 * 템플릿 객체로 부터 HTML 문자열을 반환
		 * @param {string} key 템플릿 객체의 키
		 * @param {object} item 템플릿 객체에 적용할 값의 객체
		 */
		getHTML: function(key, item) {
			var template = this.getTemplate(key);
			if (template) {
				return Mustache.to_html(template.text, template.render ? template.render(item) : item);	
			}
			return '';
		}
	};
	
	return Templates;
})('kth.puddingto.Templates'))({
	exportTo: PuddingTo
});

})(window, Zepto);