/**
 * @fileOverview data-list attribute 가 있는 엘리먼트를 리스트로 구조화 함.
 */
(function(global) {
    var API = PuddingTo.API;

    // 사진을 부를 때 에러가 나면 기본 사진으로 대체한다.
    function setDefaultPhoto(container) {
        container.find('[data-link=profile] img')
                 .error(function() {
                     this.src = PuddingTo.consts.DEFAULT_PROFILE;
                 });

        container.find('[data-link=photo] img')
                 .error(function() {
                     this.src = PuddingTo.consts.DEFAULT_PHOTO;
                 });
    }
    
    // 목록 설정을 초기화한다.
    API.prototype.reset = function() {
        var list      = this.list,
            container = list.container,
            element   = list.element || container.find('ul');

        list.cursor = 0;
        this.formData[list.cursorField] = 0;
        this.global = true;
        
        container.removeClass('p2-none p2-more p2-nomore p2-more-loading p2-called')
                 .removeAttr('data-calls');
        
        // 더보기 버튼이 숨어 있을 수 있으니 다시 보이게 한다.
        container.find('.p2-more-text').show();
        // "맨 위로" 문장으로 설정되어 있을 수 있으니 "더 보기"로 초기화한다.
        container.find('.p2-more-button a').html(PuddingTo.i18n.SEE_MORE);
                
        element.empty();
    };

    API.prototype.renderList = function(items) {
        var list      = this.list,
            container = list.container,
            element   = list.element || container.find('ul'),
            template  = PuddingTo.templates[list.template],
            exist     = !!items.length,
            first,
            more,
            fragment;

        if (list.count) {
            more  = items.length > list.count;
            first = !list.cursor;
        } else {
            more  = false;
            first = true;
        }

        if (exist) {
            if (more) {
                items.pop();
            }

            // Reflow를 방지하기 위해 사용
            fragment = document.createDocumentFragment();
            
            items.forEach(function(item) {
                // 기본 프로필 사진이 없을 경우 기본 사진을 보여준다.
                if (!item.profile_picture) {
                    item.profile_picture = PuddingTo.consts.DEFAULT_PROFILE;
                }
                
                var html = $(Mustache.to_html(template.text, template.render ? template.render(item, list.options) : item));
                setDefaultPhoto(html);
                fragment.appendChild(html.get(0));
            });
            
			element.append(fragment)
			    /* Android 4.0.x에서의 렌더링 이슈 회피
	             * - http://its.kthcorp.com/browse/PUDDINGTO-1602
	             * - http://its.kthcorp.com/browse/PUDDINGTO-1570
	             * - http://wiki.kthcorp.com/pages/viewpage.action?pageId=25569013
	             */
                .show();
        }

        if (more) {
            container.addClass('p2-more');

            list.cursor += list.count;
            this.formData[list.cursorField] = list.cursor;
        } else {
            container.removeClass('p2-more');

            if (first) {
                if (!exist) {
                    /* Android 4.0.x에서의 렌더링 이슈 회피
                     * - http://its.kthcorp.com/browse/PUDDINGTO-1602
                     * - http://its.kthcorp.com/browse/PUDDINGTO-1570
                     * - http://wiki.kthcorp.com/pages/viewpage.action?pageId=25569013
                     */
                    setTimeout(function() {
                        container.addClass('p2-none');
                    }.bind(this), 200);
                }
            } else {
                container.addClass('p2-nomore');

                if ($.os.android) {
                    container.find('.p2-more-text').hide();
                } else {
                    container.find('.p2-more-button a').html(PuddingTo.i18n.BACK_TO_TOP);
                }
            }
        }
    };
    
    API.prototype.actsAsList = function(options) {
        
        options.container = $(options.container);

        var defaults = {
            cursor     : 0,
            cursorField: 'cursor'
        };
        
        if (this.route == 'get user/connected/users' || this.route == 'get user/connected/friends') {
            this.global = false;
        }
        
        this.list = $.extend(defaults, options);
        
        if (this.list.count) {
            this.formData[this.list.cursorField] = this.list.cursor;
            this.formData.count = this.list.count;
        }
        
        
        this.list.container.removeClass('p2-none'); //없는 닉네임 검색 후, 다시 검색하면 검색어로 갱신되어버리는 문제.
        
        this.success = function(data) {
            var after = this.list.after || this.list.container.data('list-after');

            console.log(data);
            this.renderList(data);
            
            if (after) {
                if (typeof after === 'function') {
                    after.call(this, data);
                } else {
                    window[after].call(this, data);
                }
            }
        }.bind(this);
        
        this.complete = function() {
            var container = this.list.container,
                initLoader,
                calls;
            
            // 로딩중 표시를 하고 있으면 해제한다.
            initLoader = container.find('.p2-init-loader');
            
            if (initLoader.length) {
                initLoader.remove();
            }

            // API를 호출한 횟수를 갱신한다.
            calls = container.data('calls') || 0;
            container.data('calls', calls++);
        };

        
        // "더보기" 버튼 이벤트 핸들러
        this.list.container.find('.p2-more-button').off('click.actsAsList').on('click.actsAsList', function(event) {
            event.preventDefault();
            
            var container = this.list.container;
            
            if (container.hasClass('p2-more')) {
                container.addClass('p2-more-loading');
                
                this.call({
                    global: false,
                    complete: function() {
                        container.removeClass('p2-more-loading');
                    }
                });
            } else {
                scrollTop();
            }
        }.bind(this));
    };
    
    // data-list 속성이 있는 엘리먼트를 목록화한다.
    $(function() {
        $('[data-list]').each(function(index, list) {
            list = $(list);
            
            var route    = list.data('list'),
                autoload = list.data('list-autoload'),
                listOptionKey = list.data('list-option'),
                listOptions = listOptionKey ? {} : undefined;
            
            // data-list 속성을 동적으로 선언하거나 data-list-autoload="false"일 경우 진행하지 않는다.
            if (!route || autoload == 'false') {
                return;
            }
            
            // data-list-options 속성을 바탕으로 리스트에 추가적인 옵션을 설정
            if (listOptions) {
                $(listOptionKey.split(' ')).each(function(index, key){
                    listOptions[key] = PuddingTo.params[key];
                });
                route = Mustache.to_html(route, listOptions);
            }

            var api = new PuddingTo.API(route, {
                success: function(json) {
                    console.log(json);
                }
            });
            
            api.actsAsList({
                container: list,
                template : list.data('list-template'),
                count    : parseInt(list.data('list-count') || 30),
                options  : listOptions 
            });
            
            api.call();
        });
    });
}(window));
